Changelog
=========


(unreleased)
------------
- Lintwork. [lucasew]
- Fix bump everything because full name not specified + optional output
  file. [lucasew]


0.0.9 (2023-03-07)
------------------
- Release: version 0.0.9 🚀 [lucasew]
- Eval_nodes: ignore missing keys. [lucasew]
- Option to not generate minified json. [lucasew]
- Lintwork. [lucasew]
- Selective bump, bump older items first. [lucasew]
- Command to list nodes in a json. [lucasew]


0.0.8 (2023-03-06)
------------------
- Release: version 0.0.8 🚀 [lucasew]
- Save old state if assertion error when evaluating node. [lucasew]


0.0.7 (2023-03-06)
------------------
- Release: version 0.0.7 🚀 [lucasew]
- Resilience work. [lucasew]


0.0.6 (2023-03-06)
------------------
- Release: version 0.0.6 🚀 [lucasew]
- Assume old state is best if unhandled HTTP error, useful to not lose
  progress if github ratelimit kicks in. [lucasew]


0.0.5 (2023-03-06)
------------------
- Release: version 0.0.5 🚀 [lucasew]
- Lintwork. [lucasew]
- Basicgithub: minor tweaks. [lucasew]
- Flake. [lucasew]


0.0.4 (2023-03-05)
------------------
- Release: version 0.0.4 🚀 [lucasew]
- Verbose is setup globally by the logger so no need to pass verbose
  parameters around. [lucasew]
- Sources: fix bug where all bumpkin demo use the basichttpjsonvendor
  fetcher. [lucasew]


0.0.3 (2023-03-05)
------------------
- Release: version 0.0.3 🚀 [lucasew]
- README: remove '(in the future)' [lucasew]


0.0.2 (2023-03-05)
------------------
- Release: version 0.0.2 🚀 [lucasew]
- Setup.py: change pypi description. [lucasew]


0.0.1 (2023-03-05)
------------------
- Release: version 0.0.1 🚀 [lucasew]
- Actions: add missing token. [lucasew]
- Release: version 0.1.0 🚀 [lucasew]
- Actions: fix broken yaml, i guess. [lucasew]
- Actions: run linux tests before other OS tests. [lucasew]
- Lintwork. [lucasew]
- Lintwork. [lucasew]
- Add argparse descriptions. [lucasew]
- Lintwork. [lucasew]
- Source/basichttpjsonvendor: add example. [lucasew]
- Source/basichttpjsonvendor: init. [lucasew]
- Sources/basicgithub: argparse. [lucasew]
- Implement nix fetchers for plugins. [lucasew]
- Each source in a folder. [lucasew]
- Lintwork. [lucasew]
- Basicgithub: more testing. [lucasew]
- Basicgithub plugin, just need to test better after rate limit
  cooldown. [lucasew]
- Nix stuff. [lucasew]
- Update README.md. [Lucas Eduardo]
- Update README.md. [Lucas Eduardo]
- Lintwork. [lucasew]
- Rm funding. [lucasew]
- Readme. [lucasew]
- Logging tweaks. [lucasew]
- Argparse work. [lucasew]
- Basic demo cli integration. [lucasew]
- Basic source work. [lucasew]
- Add shell.nix. [lucasew]
- ✅ Ready to clone and code. [lucasew]
- Initial commit. [Lucas Eduardo]


